@@ -9,7 +9,6 @@ sub gnFirstRun {
    #
    # 引数: なし
    # 返り値: なし
-   #my $gladefn = $_[0];
    
    # Step 1
    # 設定ファイルを格納するディレクトリをFreedesktop.org XDG Base Directory Specに
@@ -194,36 +193,30 @@ sub gnFR_finish {
          $main::tmpdir = &gnGetEnvVal('XDG_CACHE_HOME') . "\/gnview\/";
       }
    }
-   #$main::tmpdir = $gnCfgPath . "cache";
    if($main::tmpdir eq "") {
       my $dir = &gnGetEnvVal('HOME') . "\/.cache\/";
       if(&gnCheckPath($dir)) {
          $main::tmpdir = $dir . "\/gnview\/";
       }
    }
+#   if($main::tmpdir eq "") {
+#      my $dir = $gnCfgPath . "\/cache\/";
+#      if(&gnCheckPath($dir)) {
+#         $main::tmpdir = $dir;
+#      }
+#   }
    if($main::tmpdir eq "") {
-      my $dir = $gnCfgPath . "\/cache\/";
-      if(&gnCheckPath($dir)) {
-         $main::tmpdir = $dir;
-      }
-   }
-   if($main::tmpdir eq "") {
-      if(&gnCheckPath("\/tmp")) {
-         $main::tmpdir = "\/tmp";
-      }
+         $main::tmpdir = &gnGetEnvVal('HOME') . "\/.gnview\/cache\/";
    }
    if(!(&gnCheckPath($main::tmpdir))) {
       &gnMakeDir($main::tmpdir);
-      #mkdir($main::tmpdir);
       $str .= "\[キャッシュ保存用フォルダ\]\n  $main::tmpdir\n";
    }
    # 画像キャッシュテーブルの初期化
    $gnInitCfg{'Main'}{'cachetbl.ini'} = $gnCfgPath . "cachetbl.ini";
    if (!(&gnCheckPath($gnInitCfg{'Main'}{'cachetbl.ini'}))) {
       &gnOpenLocal($gnInitCfg{'Main'}{'cachetbl.ini'}, "w");
-      #open(gnCTBL, ">$gnInitCfg{'Main'}{'cachetbl.ini'}");
       &gnCloseLocal($gnInitCfg{'Main'}{'cachetbl.ini'});
-      #close(gnCTBL);
    }
 
 
@@ -265,117 +258,19 @@ sub gnFR_finish {
       $gnURLIniFile = $gnInitCfg{'Main'}{'url.ini'};
       $gnSentIniFile = $gnInitCfg{'Main'}{'sent.ini'};
       
-      
-#      my $str = "";
-#      #my $logdir_1 = Encode::encode(&env_locale_to_encstr($ENV{'LANG'}), $logdir);
-#      if (!(&gnCheckPath($logdir))) {
-#                &gnMakeDir($logdir);
-#                #mkdir($logdir_1);
-#                $str = "\[ログ保存用フォルダ\]\n  $logdir\n";
-#      }
-#
-#      # <設定ディレクトリ>/.gnviewconfigへ書き込み
-#      if (!(&gnCheckPath($gnCfgPath))) {
-#                &gnMakeDir($gnCfgPath);
-#                #mkdir($gnCfgPath);
-#                $str .= "\[設定保存用フォルダ\]\n  $gnCfgPath\n";
-#      }
-#      
-#      # キャッシュフォルダの初期化
-#      # キャッシュファイルを格納するディレクトリをFreedesktop.org XDG Base Directory Specに
-#      # 従って確定する(環境変数HOMEは必ずあるという前提)
-#      
-#	  $main::tmpdir = "";
-#	  if(&gnGetEnvVal('XDG_CACHE_HOME')) {
-#	     if(&gnCheckPath(&gnGetEnvVal('XDG_CACHE_HOME'))) {
-#	        $main::tmpdir = &gnGetEnvVal('XDG_CACHE_HOME') . "\/gnview\/";
-#	     }
-#	  }
-#	  #$main::tmpdir = $gnCfgPath . "cache";
-#	  if($main::tmpdir eq "") {
-#	     my $dir = &gnGetEnvVal('HOME') . "\/.cache\/";
-#	     if(&gnCheckPath($dir)) {
-#	        $main::tmpdir = $dir . "\/gnview\/";
-#	     }
-#	  }
-#	  
-#	  if($main::tmpdir eq "") {
-#	     my $dir = $gnCfgPath . "\/cache\/";
-#	     if(&gnCheckPath($dir)) {
-#	        $main::tmpdir = $dir;
-#	     }
-#	  }
-#	  
-#	  if($main::tmpdir eq "") {
-#	     if(&gnCheckPath("\/tmp")) {
-#	        $main::tmpdir = "\/tmp";
-#	     }
-#	  }
-#	  
-#      if(!(&gnCheckPath($main::tmpdir))) {
-#         &gnMakeDir($main::tmpdir);
-#         #mkdir($main::tmpdir);
-#         $str .= "\[キャッシュ保存用フォルダ\]\n  $main::tmpdir\n";
-#      }
-#      
-#      # 画像キャッシュテーブルの初期化
-#      $gnInitCfg{'Main'}{'cachetbl.ini'} = $gnCfgPath . "cachetbl.ini";
-#      if (!(&gnCheckPath($gnInitCfg{'Main'}{'cachetbl.ini'}))) {
-#         &gnOpenLocal($gnInitCfg{'Main'}{'cachetbl.ini'}, "w");
-#         #open(gnCTBL, ">$gnInitCfg{'Main'}{'cachetbl.ini'}");
-#         &gnCloseLocal($gnInitCfg{'Main'}{'cachetbl.ini'});
-#         #close(gnCTBL);
-#      }
-#      
-#      # フォルダ作成通知
-#      if($str ne "") {
-#             $str = "以下のフォルダを作成しました\n\n" . $str;
-#             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
-#             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
-#                                                           'GTK_DIALOG_MODAL',
-#                                                           'GTK_MESSAGE_INFO',
-#                                                           'GTK_BUTTONS_OK',
-#                                                           $str,
-#                                                           ,
-#                                                           'GTK_BUTTONS_OK' => 'gtk-ok');
-#             if($gnMsgDialog->run eq 'ok') {
-#                $gnMsgDialog->destroy;
-#             }
-#      }
-#      
-#      my $gnInitCfgFN = $gnCfgPath . ".gnviewconfig";
-#      $gnInitCfg{'Main'}{'gnCfgPath'} = $gnCfgPath;
-#      if($gnDebugFlag) { print Dumper(%gnInitCfg); }
-#      &gnSaveEnv($gnInitCfgFN, \%gnInitCfg);
-#      
-#      my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
-#      $gnFirstRunGUI->destroy;
-#      
-#      &gnInit;
       #####################################################################
    }else{
       # Step 3-2
       # 「新規に作成」した場合の終了処理
       #####################################################################
       
-#      # <設定ディレクトリ>を作成
-#      my $str = "";
-#      if (!(&gnCheckPath($gnCfgPath))) {
-#                &gnMakeDir($gnCfgPath);
-#                #mkdir($gnCfgPath);
-#                $str = "\[設定保存用フォルダ\]\n  $gnCfgPath\n";
-#      }
       # 各種設定ファイルのスケルトンを共有ディレクトリから設定ディレクトリにコピー
       my $gngikoNaviIni_from = &gnGetLibPath . "gikoNavi.ini";
       my $gnurlIni_from = &gnGetLibPath . "url.ini";
       my $gnsentIni_from = &gnGetLibPath . "sent.ini";
       &gnFCopy($gngikoNaviIni_from, $gnCfgPath);
-      #copy($gngikoNaviIni_from, $gnCfgPath);
       &gnFCopy($gnurlIni_from, $gnCfgPath);
-      #copy($gnurlIni_from, $gnCfgPath);
       &gnFCopy($gnsentIni_from, $gnCfgPath);
-      #copy($gnsentIni_from, $gnCfgPath);
-
       
       $gnInitCfg{'Main'}{'gikoNavi.ini'} = $gnCfgPath . "gikoNavi.ini";
       if($gnDebugFlag) { print "$gnInitCfg{'Main'}{'gikoNavi.ini'}\n"; }
@@ -387,82 +282,14 @@ sub gnFR_finish {
       my $gnFRLog = $gnFRxml->get_widget('gnFirstrun_LogDirChoose_init');
       if($gnDebugFlag) { print STDERR "1\n"; }
       my $gnFRLog_fn = $gnFRLog->get_filename;
-      #$gnFRLog_fn = Glib::filename_display_name($gnFRLog_fn);
       $gnInitCfg{'Main'}{'LogFolder'} = Glib::filename_display_name($gnFRLog_fn);
 
-      #my $bbb = Encode::encode(&env_locale_to_encstr($ENV{'LANG'}), $gnFRLog_fn);
-      #if($gnDebugFlag) { print STDERR "2\: $gnFRLog_fn\n"; }
-      #if($gnDebugFlag) { print STDERR "2\: $bbb\n"; }
-      #if($gnDebugFlag) { print "Main_LogFolder\: " . "$gnInitCfg{'Main'}{'LogFolder'}\n"; }
       $logdir = $gnInitCfg{'Main'}{'LogFolder'} . "\/2ch\/";
-      #$logdir = Encode::encode(&env_locale_to_encstr($ENV{'LANG'}), $logdir);
       if($gnDebugFlag) { print "logdir\: " . "$logdir\n"; }      
 
-      #if($gnDebugFlag) {
-      #print STDERR "3\: $gnFRLog_fn\n";
-      #print STDERR "3\: $bbb\n";
-      #if(&gnCheckPath($gnFRLog_fn)) {
-      #   print STDERR "Directory exist.\n";
-      #}else{
-      #   print STDERR "Directory does\'t exist.\n";
-      # }
-      #}
-
-      #$gnInitCfg{'Main'}{'LogFolder'} = $gnFRLog_fn;
-      #if($gnDebugFlag) { print STDERR "4\: $gnFRLog_fn\n"; }
-      
       $gnEnvFile = $gnInitCfg{'Main'}{'gikoNavi.ini'};
       $gnURLIniFile = $gnInitCfg{'Main'}{'url.ini'};
       $gnSentIniFile = $gnInitCfg{'Main'}{'sent.ini'};
-      
-#      if (!(&gnCheckPath($logdir))) {
-#                &gnMakeDir($logdir);
-#                #mkdir($logdir);
-#                $str .= "\[ログ保存用フォルダ\]\n  $logdir\n";
-#      }
-#
-#      # キャッシュフォルダの初期化
-#      $main::tmpdir = $gnCfgPath . "cache";
-#      if(!(&gnCheckPath($main::tmpdir))) {
-#         &gnMakeDir($main::tmpdir);
-#         #mkdir($main::tmpdir);
-#         $str .= "\[キャッシュ保存用フォルダ\]\n  $main::tmpdir\n";
-#      }
-#      
-#      # 画像キャッシュテーブルの初期化
-#      $gnInitCfg{'Main'}{'cachetbl.ini'} = $gnCfgPath . "cachetbl.ini";
-#      if (!(&gnCheckPath($gnInitCfg{'Main'}{'cachetbl.ini'}))) {
-#         &gnOpenLocal($gnInitCfg{'Main'}{'cachetbl.ini'}, "w");
-#         #open(gnCTBL, ">$gnInitCfg{'Main'}{'cachetbl.ini'}");
-#         &gnCloseLocal($gnInitCfg{'Main'}{'cachetbl.ini'});
-#         #close(gnCTBL);
-#      }
-#      
-#      # フォルダ作成通知
-#      if($str ne "") {
-#             $str = "以下のフォルダを作成しました\n\n" . $str;
-#             my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
-#             my $gnMsgDialog = Gtk2::MessageDialog->new($gnFirstRunGUI,
-#                                                           'GTK_DIALOG_MODAL',
-#                                                           'GTK_MESSAGE_INFO',
-#                                                           'GTK_BUTTONS_OK',
-#                                                           $str,
-#                                                           ,
-#                                                           'GTK_BUTTONS_OK' => 'gtk-ok');
-#             if($gnMsgDialog->run eq 'ok') {
-#                $gnMsgDialog->destroy;
-#             }
-#      }
-#      
-#      my $gnInitCfgFN = $gnCfgPath . ".gnviewconfig";
-#      $gnInitCfg{'Main'}{'gnCfgPath'} = $gnCfgPath;
-#      if($gnDebugFlag) { print Dumper(%gnInitCfg); }
-#      &gnSaveEnv($gnInitCfgFN, \%gnInitCfg);
-#      
-#      my $gnFirstRunGUI = $gnFRxml->get_widget('gnInitialConfig');
-#      $gnFirstRunGUI->destroy;
-#      
-#      &gnInit;
 
       #####################################################################
    
