@@ -15,19 +15,19 @@ use Data::Dumper;
 
 
 #=======================================================
-my $gnDebugFlag : shared = 2;		# デバッグレベル指定(0 = まったく出力しない, 1-->大きくなるほど詳細な
-									# デバッグ出力が行われる)
+my $gnDebugFlag : shared = 2;       # デバッグレベル指定(0 = まったく出力しない, 1-->大きくなるほど詳細な
+                                    # デバッグ出力が行われる)
 my $stepflg = 1;
-my @gnReqLibs = ("Compress::Zlib",	"Config",		"Data::Dumper",		"Encode",
-                   "Encode::Guess",	"Fcntl", "File::Basename",	"File::Copy",		"File::Path",
-                   "Glib",		"Gtk2",			"Gtk2::GladeXML",	"Gtk2::Pango",
-                   "HTML::Entities",	"HTML::TokeParser",	"HTTP::Cookies",	"HTTP::Date",
-                   "LWP::MediaTypes",	"LWP::UserAgent",	"List::Util",		"POSIX",
-                   "Storable",		"Thread::Queue",	"Time::HiRes",		"Time::Local",
-                   "URI::file",		"threads",		"threads::shared",	"utf8", "Fcntl");
+my @gnReqLibs = ("Compress::Zlib",  "Config",       "Data::Dumper",     "Encode",
+                   "Encode::Guess", "Fcntl", "File::Basename",  "File::Copy",       "File::Path",
+                   "Glib",      "Gtk2",         "Gtk2::GladeXML",   "Gtk2::Pango",
+                   "HTML::Entities",    "HTML::TokeParser", "HTTP::Cookies",    "HTTP::Date",
+                   "LWP::MediaTypes",   "LWP::UserAgent",   "List::Util",       "POSIX",
+                   "Storable",      "Thread::Queue",    "Time::HiRes",      "Time::Local",
+                   "URI::file",     "threads",      "threads::shared",  "utf8", "Fcntl");
 my $gnUserLang;
 my $gnPerlpath;
-our $gnGnname = "gnview";		# gnviewの名前
+our $gnGnname = "gnview";       # gnviewの名前
 require(".\/${gnGnname}_lowlevel.pl");
 
 for(;;) {
@@ -133,18 +133,18 @@ for(;;) {
    }
 # Step 4 (gnviewのインストールパスを指定)=========
    # インストール先の設定
-   my $binpath		= &gnGetBinPath;
-   my $sharepath	= &gnGetLibPath;
-   my $manpath		= $sharepath . "man\/";
+   my $binpath      = &gnGetBinPath;
+   my $sharepath    = &gnGetLibPath;
+   my $manpath      = $sharepath . "man\/";
    
    # インストール対象ファイルの設定
-   my @instfile_bin		= ("gnview");
-   my @instfile_share	= ("gnview_firstrun.pl",	"gnview_env.pl",	"gnview_lowlevel.pl",	"1pix.png",
-   							"1pix_glay.png",		"gnview.png",		"gnview.glade",			"gikoNavi.ini",
-   							"url.ini",				"sent.ini");
-   my @instfile_desktop	= ("gnview.desktop");
-   my @instfile_icon	= ("gnview.png");
-   my @instfile_doc		= ("AUTHORS", "COPYING", "ChangeLog", "NEWS", "README", "TODO");
+   my @instfile_bin     = ("gnview");
+   my @instfile_share   = ("gnview_firstrun.pl",    "gnview_env.pl",    "gnview_lowlevel.pl",   "1pix.png",
+                            "1pix_glay.png",        "gnview.png",       "gnview.glade",         "gikoNavi.ini",
+                            "url.ini",              "sent.ini");
+   my @instfile_desktop = ("gnview.desktop");
+   my @instfile_icon    = ("gnview.png");
+   my @instfile_doc     = ("AUTHORS", "COPYING", "ChangeLog", "NEWS", "README", "TODO", "THANKS");
    my @instfile_man;
    if ($^O eq "solaris") {
       @instfile_man = ("gnview.1");
@@ -448,10 +448,10 @@ sub gnGetLibPath {
          return($gnLibPath);
       }
    }else{
-	  # Windowsでない場合はFreedesktop.org Specification準拠に従って
-	  # ライブラリパスを探索する。
-	  # ヒットした時点でreturn。
-	  if(&gnGetEnvVal('XDG_DATA_DIRS')) {
+      # Windowsでない場合はFreedesktop.org Specification準拠に従って
+      # ライブラリパスを探索する。
+      # ヒットした時点でreturn。
+      if(&gnGetEnvVal('XDG_DATA_DIRS')) {
          my @dvars = split(/:/, &gnGetEnvVal('XDG_DATA_DIRS'));
          foreach my $dvar(@dvars) {
             chomp($dvar);
@@ -462,7 +462,7 @@ sub gnGetLibPath {
             }
          }
       }
-	  my @dvars = ('/usr/local/share/', '/usr/share/');
+      my @dvars = ('/usr/local/share/', '/usr/share/');
       foreach my $dvar(@dvars) {
          chomp($dvar);
          $gnLibPath = $dvar;
@@ -513,18 +513,18 @@ sub env_locale_to_encstr {
      }
     
     # あとはパターンマッチ
-    if    ($myLocStr[1] eq "932")			{ return('cp932');
-    }elsif($myLocStr[1] eq "pck")			{ return('cp932');
-    }elsif($myLocStr[1] eq "sjis")			{ return('shiftjis');
-    }elsif($myLocStr[1] eq "20932")		{ return('euc-jp');
-    }elsif($myLocStr[1] eq "eucjp")		{ return('euc-jp');
-    }elsif($myLocStr[1] eq "euc-jp")		{ return('euc-jp');
-    }elsif($myLocStr[1] eq "euc")			{ return('euc-jp');
-    }elsif($myLocStr[1] eq "ujis")			{ return('euc-jp');
-    }elsif($myLocStr[1] eq "iso-2022-jp")	{ return('iso-2022-jp');
-    }elsif($myLocStr[1] eq "utf-8")		{ return('utf8');
-    }elsif($myLocStr[1] eq "utf8")			{ return('utf8');
-    }else										{ return('ascii'); # エンコードが判別できなかったらシングルバイトエンコード(単なるバイト列)として解釈する
+    if    ($myLocStr[1] eq "932")           { return('cp932');
+    }elsif($myLocStr[1] eq "pck")           { return('cp932');
+    }elsif($myLocStr[1] eq "sjis")          { return('shiftjis');
+    }elsif($myLocStr[1] eq "20932")     { return('euc-jp');
+    }elsif($myLocStr[1] eq "eucjp")     { return('euc-jp');
+    }elsif($myLocStr[1] eq "euc-jp")        { return('euc-jp');
+    }elsif($myLocStr[1] eq "euc")           { return('euc-jp');
+    }elsif($myLocStr[1] eq "ujis")          { return('euc-jp');
+    }elsif($myLocStr[1] eq "iso-2022-jp")   { return('iso-2022-jp');
+    }elsif($myLocStr[1] eq "utf-8")     { return('utf8');
+    }elsif($myLocStr[1] eq "utf8")          { return('utf8');
+    }else                                       { return('ascii'); # エンコードが判別できなかったらシングルバイトエンコード(単なるバイト列)として解釈する
     }
 
     
